@@ -2,10 +2,10 @@ OC.L10N.register(
     "circles",
     {
     "Circles" : "Vòng kết nối",
-    "Circles' files" : "Các tệp tin của các vòng kết nối",
+    "Circles' files" : "Tệp tin của các vòng kết nối",
     "Select circles to filter by" : "Chọn các vòng kết nối để lọc bởi",
     "No circles found" : "Không có vòng kết nối được tìm thấy",
-    "Please select circles to filter by" : "Vui lòng chọn các vòng kết nới để lọc bởi",
+    "Please select circles to filter by" : "Vui lòng chọn các vòng kết nối để lọc bởi",
     "No files found for the selected circles" : "Không có tệp được tìm thấy cho vòng kết nối được chọn",
     "You created the circle {circle}" : "Bạn đã tạo một vòng kết nối {circle}",
     "{author} created the circle {circle}" : "{author} đã tạo một vòng kết nối {circle}",
@@ -75,32 +75,62 @@ OC.L10N.register(
     "On events happening in a <strong>Circle</strong> of which you are a member" : "Trên những sự kiên đang diễn ra trong một <strong> Vòng kết nối </strong> mà bạn là thành viên của nhóm",
     "Any important event in a <strong>Circle</strong> you are moderating" : "Một sự kiện quan trọng trong một <strong> Vòng kết nối </strong> mà bạn đang điều hành",
     "On global events happening in any <strong>Circle</strong>" : "Trên những sự kiện chung đang diễn ra của tổ chức trong bất cứ <strong> Vòng kết nối </strong>",
+    "Shared to Circles" : "Đã được chia sẻ đến những Vòng kết nối",
+    "Single" : "Riêng lẻ",
     "Personal" : "Cá nhân",
+    "System" : "Hệ thống",
+    "Visible" : "Có thể nhìn thấy",
     "Open" : "Mở",
+    "Invite" : "Mời",
+    "Join Request" : "Yêu cầu tham gia",
+    "Friends" : "Bạn bè",
+    "Password Protected" : "Được bảo vệ mật khẩu",
+    "No Owner" : "Không có chủ sở hữu",
     "Hidden" : "Ẩn",
+    "Backend" : "Backend",
+    "Local" : "Cục bộ(ngoại tuyến)",
+    "Root" : "Gốc",
+    "Circle Invite" : "Mời vòng kết nối",
     "Federated" : "Federated",
+    "Mount point" : "Điểm gắn",
+    "Nextcloud Account" : "Tài khoản Nextcloud",
+    "Nextcloud Group" : "Nhóm Nextcloud",
+    "Email Address" : "Địa chỉ email",
     "Contact" : "Liên hệ",
     "Circle" : "Vòng kết nối",
+    "Nextcloud App" : "Ứng dụng Nextcloud",
     "Member" : "Thành viên",
     "Moderator" : "Kiểm duyệt",
     "Admin" : "Quản trị",
     "Owner" : "Chủ",
     "%s shared »%s« with you." : "%s đã chia sẻ »%s« với bạn",
+    "%s shared »%s« with \"%s\"." : "%s đã chia sẻ »%s« với \"%s\".",
     "%s on %s" : "%s trên %s",
+    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s đã chia sẻ »%2$s« với bạn.\nBạn sẽ nhận được một email riêng có liên kết để truy cập nó.\n",
+    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s đã chia sẻ »%2$s« với bạn. Bạn sẽ nhận được một email riêng có liên kết để truy cập nó.",
     "Password to access »%1$s« shared to you by %2$s" : "Mật khẩu để truy cập »%1$s« đã được chia sẻ tới bạn bởi %2$s",
     "Password to access »%s«" : "Mật khẩu để truy cập »%s«",
     "It is protected with the following password:" : "Nó được bảo vệ bởi mật khẩu sau đây:",
     "%1$s via %2$s" : "%1$s thông qua %2$s",
     "Click the button below to open it." : "Bấm vào nút bên dưới để mở nó.",
     "Open »%s«" : "Mở »%s«",
+    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s đã chia sẻ nhiều tệp tin với bạn.\nBạn sẽ nhận được một email riêng có liên kết để truy cập chúng.\n",
+    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s đã chia sẻ nhiều tệp tin với bạn. Bạn sẽ nhận được một email riêng có liên kết để truy cập chúng.",
     "Password to access files shared to you by %1$s" : "Mật khẩu để truy cập vào các tệp đã được chia sẻ tới bạn bởi %1$s",
     "Password to access files" : "Mật khẩu để truy cập các tệp",
+    "%s shared multiple files with \"%s\"." : "%s đã chia sẻ nhiều tệp với \"%s\".",
     "%s shared multiple files with you." : "%s đã chia sẻ tổ hợp tệp với bạn.",
+    "Boot up" : "Khởi động lên",
+    "Nextcloud Initialization" : "Khởi tạo Nextcloud",
+    "Circles App Initialization" : "Khởi tạo Ứng dụng vòng kết nối",
+    "Fresh installation status" : "Trạng thái cài đặt mới",
+    "Building Local Database" : "Đang xây dựng cơ sở dữ liệu cục bộ",
+    "Testing Basic Circle Creation" : "Đang kiểm tra Tạo vòng kết nối cơ bản",
+    "Adding local users and moderators" : "Đang thêm người dùng và người quản lý",
     "Circle not found" : "Vòng kết nối không được tìm thấy",
     "Circle not found " : "Vòng kết nối không được tìm thấy",
-    "A circle with that name exists" : "Đã tồn tại một vòng kết nối có tên đó",
-    "You cannot use the Circles Application until your administrator has allowed at least one type of circles" : "Bạn không thể sử dụng Ứng dụng Vòng kết nối cho đến khi quản trị viên của bạn cho phép ít nhất một loại của vòng kết nối",
     "This member does not exist" : "Thành viên này không tồn tại",
+    "This account is already a member of the circle" : "Tài khoản này đã là thành viên của Vòng kết nối",
     "Federated link not found" : "Liên kết Liên Bang không thể được tìm thấy",
     "This feature is not available for personal circles" : "Tính năng này không khả dụng cho các vòng kết nối cá nhân",
     "The circle is not federated" : "Vòng kết nối không được chia sẻ liên bang",
@@ -111,14 +141,20 @@ OC.L10N.register(
     "Level cannot be changed for this type of member" : "Cấp độ không thể được thay đổi cho kiểu loại của thành viên này",
     "You are already a member of this circle" : "Bạn đã là thành viên của vòng kết nối này",
     "You have been blocked from this circle" : "Bạn đã bị chặn khỏi vòng kết nối này",
+    "The account is already a member of this circle" : "Tài khoản này đã là thành viên của Vòng kết nối này",
+    "The account has already been invited into this circle" : "Tài khoản này đã được mời vào Vòng kết nối này",
+    "%s (Circle owned by %s)" : "%s (Vòng kết nối được sở hữu bởi %s)",
     "You are now a member of the Circle \"%2$s\"" : "Bây giờ bạn là thành viên của Vòng kết nối \"%2$s\"",
     "You have been invited by %1$s into the Circle \"%2$s\"" : "Bạn vừa mới được mời bởi %1$s vào Vòng kết nối \"%2$s\"",
     "%1$s sent a request to be a member of the Circle \"%2$s\"" : "%1$s đã gửi một yêu cầu để là một thành viên của Vòng kết nối \"%2$s\"",
     "Accept" : "Đồng ý",
     "Refuse" : "Từ chối",
     "Leave the circle" : "Rời bỏ vòng kết nối",
+    "%s" : "%s",
     "Personal Circle" : "Vòng cá nhân",
+    "%s owned by %s" : "%s được sở hữu bởi %s",
     "You need a specify a type of circle" : "Bạn cần xác định một kiểu loại của vòng kết nối",
+    "A circle with that name exists" : "Đã tồn tại một vòng kết nối có tên đó",
     "This member is not the owner of the circle" : "Thành viên này không phải là chủ nhân của vòng kết nối",
     "This member is not an admin of the circle" : "Thành viên này không phải là một quản trị viên của vòng kết nối này",
     "Group contains too many members" : "Nhóm chứa quá nhiều thành viên",
@@ -127,18 +163,27 @@ OC.L10N.register(
     "You cannot edit level in a personal circle" : "Bạn không thể sửa đổi mức độ trong một vòng kết nối cá nhân",
     "Group cannot be set as owner of a circle" : "Nhóm không thể được đặt với tư cách là chủ nhận của một vòng kết nối",
     "now" : "bây giờ",
+    "This account does not exist" : "Tài khoản này không tồn tại",
     "Email format is not valid" : "Định dạng thư điện tử không hợp lệ",
     "This contact is not available" : "Liên hệ này không khả dụng",
-    "Could not find share" : "Không thể tìm thấy chia sẻ",
+    "You have no permission to create a new circle" : "Bạn không có quyền để tạo vòng kết nối mới",
+    "%s shared a file with \"%s\"." : "%s đã chia sẻ một tệp tin với \"%s\".",
+    "%s shared a file with you." : "%s đã chia sẻ một tệp tin với bạn.",
+    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s đã chia sẻ một vài nội dung với bạn.\nBạn sẽ nhận được một email riêng có liên kết để truy cập chúng.\n",
+    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s đã chia sẻ một vài nội dung với bạn. Bạn sẽ nhận được một email riêng có liên kết để truy cập chúng.",
+    "Password to access content shared with you by %1$s" : "Mật khẩu để truy cập nội dung được chia sẻ với bạn bởi %1$s",
+    "Password to access content" : "Mật khẩu để truy cập nội dung",
+    "This item is already shared with this circle" : "Mục này đã được chia sẻ với vòng kết nối này",
     "Bring cloud-users closer together." : "Mang các người dùng-điện toán đám mây đến gần nhau hơn",
+    "Circles allows people to create their own groups of people/colleagues/friends.\nThose groups of people (or \"circles\") can then be used by any other app for sharing purpose." : "Vòng kết nối cho phép mọi người tạo nhóm người/đồng nghiệp/bạn bè của riêng họ.\nNhững nhóm người đó (hoặc \"vòng kết nối\") sau đó có thể được bất kỳ ứng dụng nào khác sử dụng cho mục đích chia sẻ.",
     "No files in here" : "Không có tệp ở đây",
     "No entries found in this folder" : "Chưa có mục nào trong thư mục",
     "Name" : "Tên",
     "Size" : "Kích cỡ",
     "Modified" : "Thay đổi",
-    "This user is already a member of the circle" : "Người dùng này đã là thành viên của vòng kết nối",
-    "The user is already a member of this circle" : "Người dùng này đã là thành viên của vòng kết nối này",
-    "The user has already been invited into this circle" : "Người dùng này đã được mời vào vòng kết nối này",
-    "This user does not exist" : "Người dùng này không tòn tại"
+    "Initialisation Nextcloud" : "Khởi tạo Nextcloud",
+    "Initialisation Circles App" : "Khởi tạo Ứng dụng vòng kết nối",
+    "You cannot use the Circles Application until your administrator has allowed at least one type of circles" : "Bạn không thể sử dụng Ứng dụng Vòng kết nối cho đến khi quản trị viên của bạn cho phép ít nhất một loại của vòng kết nối",
+    "Could not find share" : "Không thể tìm thấy chia sẻ"
 },
 "nplurals=1; plural=0;");
