@@ -8,6 +8,7 @@ OC.L10N.register(
     "Federated" : "연합",
     "Only synchronize to trusted servers" : "신뢰할 수 있는 서버만 동기화할 수 있습니다.",
     "Published" : "발행됨",
+    "Synchronize to trusted servers and the global and public address book" : "신뢰할 수 있는 서버와 전역 및 개인 연락처에 동기화",
     "Verify" : "확인",
     "Verifying …" : "확인 중 …",
     "Unable to change password" : "암호를 변경할 수 없음",
@@ -33,12 +34,10 @@ OC.L10N.register(
     "{actor} changed your password" : "{actor} 님이 내 암호를 변경함",
     "You changed your password" : "내 암호를 변경함",
     "Your password was reset by an administrator" : "관리자가 내 암호를 초기화함",
-    "Your password was reset" : "비밀번호가 재설정 되었습니다",
+    "Your password was reset" : "암호가 재설정 되었습니다.",
     "{actor} changed your email address" : "{actor} 님이 내 이메일 주소를 변경함",
     "You changed your email address" : "내 이메일 주소를 변경함",
     "Your email address was changed by an administrator" : "관리자가 내 이메일 주소를 변경함",
-    "You created app password \"{token}\"" : "앱 패스워드 \"{token}\"이 생성되었습니다.",
-    "An administrator created app password \"{token}\"" : "관리자가 앱 패스워드 \"{token}\"을(를) 생성함",
     "You deleted app password \"{token}\"" : "앱 패스워드 \"{token}\"이 제거되었습니다.",
     "You renamed app password \"{token}\" to \"{newToken}\"" : "앱 패스워드 \"{token}\"의 이름을 \"{newToken}\"으로 바꿨습니다.",
     "You granted filesystem access to app password \"{token}\"" : "앱 패스워드 \"{token}\"에 대해 파일 시스템 접근을 허가함",
@@ -49,6 +48,7 @@ OC.L10N.register(
     "Remote wipe was started on %1$s" : "원격 제거가 %1$s에 시작됨",
     "Remote wipe has finished on %1$s" : "원격 제거가 %1$s에 완료됨",
     "Your <strong>password</strong> or <strong>email</strong> was modified" : "내 <strong>암호</strong> 및 <strong>이메일</strong>이 변경됨",
+    "Apps" : "앱",
     "Could not remove app." : "앱을 삭제할 수 없음",
     "Could not update app." : "앱을 업데이트 할 수 없음",
     "Wrong password" : "잘못된 암호",
@@ -72,6 +72,8 @@ OC.L10N.register(
     "The maximum number of OPcache keys is nearly exceeded. To assure that all scripts can be kept in the cache, it is recommended to apply <code>opcache.max_accelerated_files</code> to your PHP configuration with a value higher than <code>%s</code>." : "곧 OPcache key가 최대치를 초과할 것으로 보입니다. 모든 스크립트가 캐시에 유지될 수 있도록, PHP 설정에서 <code>opcache.max_accelerated_files</code> 값을 <code>%s</code> 보다 크게 적용하시길 권장합니다. ",
     "The OPcache buffer is nearly full. To assure that all scripts can be hold in cache, it is recommended to apply <code>opcache.memory_consumption</code> to your PHP configuration with a value higher than <code>%s</code>." : "곧 OPcache 버퍼가 가득 찰 것으로 보입니다. 모든 스크립트가 캐시에 보관될 수 있도록, PHP 설정에서 <code>opcache.memory_consumption</code> 값을 <code>%s</code> 보다 크게 적용하시길 권장합니다. ",
     "The OPcache interned strings buffer is nearly full. To assure that repeating strings can be effectively cached, it is recommended to apply <code>opcache.interned_strings_buffer</code> to your PHP configuration with a value higher than <code>%s</code>." : "곧 OPcache interned buffer가 가득 찰 것으로 보입니다. 반복 문자열이 효율적으로 캐싱될 수 있도록, PHP 설정에서 <code>opcache.interned_strings_buffer</code> 값을 <code>%s</code> 보다 크게 적용하시길 권장합니다. ",
+    "Administrator documentation" : "관리자 문서",
+    "User documentation" : "사용자 문서",
     "Invalid SMTP password." : "SMTP 암호가 잘못되었습니다.",
     "Email setting test" : "이메일 설정 시험",
     "Well done, %s!" : "%s 님, 잘 하셨습니다!",
@@ -79,6 +81,7 @@ OC.L10N.register(
     "Email could not be sent. Check your mail server log" : "이메일을 보낼 수 없습니다. 메일 서버 로그를 확인하십시오.",
     "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "이메일을 보내는 중 오류가 발생했습니다. 설정을 확인하십시오.(오류: %s)",
     "You need to set your user email before being able to send test emails. Go to %s for that." : "이메일 발송 테스트를 진행하기 앞서 당신의 사용자 이메일을 설정해야 합니다. 설정을 위해 %s(으)로 가십시오.",
+    "Users" : "사용자",
     "Invalid user" : "잘못된 사용자",
     "Invalid mail address" : "잘못된 이메일 주소",
     "Settings saved" : "설정 저장됨",
@@ -110,7 +113,6 @@ OC.L10N.register(
     "Go to %s" : "%s(으)로 이동",
     "Install Client" : "클라이언트 설치",
     "Logged in user must be a subadmin" : "로그인한 사용자는 부관리자여야 합니다.",
-    "Apps" : "앱",
     "Settings" : "설정",
     "Personal" : "개인",
     "Administration" : "관리",
@@ -120,7 +122,8 @@ OC.L10N.register(
     "Overview" : "개요",
     "Basic settings" : "기본 설정",
     "Sharing" : "공유",
-    "Availability" : "가능한 시간대",
+    "Availability" : "가용성",
+    "Calendar" : "달력",
     "Personal info" : "개인 정보",
     "Mobile & desktop" : "모바일 & 데스크톱",
     "Email server" : "이메일 서버",
@@ -144,9 +147,9 @@ OC.L10N.register(
     "Nextcloud settings" : "Nextcloud 환경설정",
     "Here you can decide which group can access certain sections of the administration settings." : "이곳에서 각 설정 메뉴별로 해당 메뉴에 접근 가능한 그룹을 지정할 수 있습니다.",
     "None" : "없음",
-    "Unable to modify setting" : "설정을 수정할 수 없습니다",
+    "Unable to modify setting" : "설정을 수정할 수 없습니다.",
     "Two-Factor Authentication" : "2단계 인증",
-    "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "2단계 인증을 모든 유저 또는 특정 그룹에 강제할 수 있습니다. 만약 대상자가 2단계 인증 공급자를 설정하지 않았다면, 대상자는 시스템에 접근할 수 없게 될 것입니다.",
+    "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "2단계 인증을 모든 사용자 또는 특정 그룹에 강제할 수 있습니다. 만약 대상자가 2단계 인증 공급자를 설정하지 않았다면, 대상자는 시스템에 접근할 수 없게 될 것입니다.",
     "Enforce two-factor authentication" : "2단계 인증 강제하기",
     "Limit to groups" : "그룹으로 제한",
     "Enforcement of two-factor authentication can be set for certain groups only." : "2단계 인증 강제는 특정 그룹에게만 적용됩니다.",
@@ -154,7 +157,7 @@ OC.L10N.register(
     "Enforced groups" : "강제된 그룹",
     "Two-factor authentication is not enforced for members of the following groups." : "2단계 인증이 강제되지 않은 그룹은 다음과 같습니다.",
     "Excluded groups" : "제외된 그룹",
-    "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "그룹이 선택되거나 제외되었을 때, 다음과 같은 상황을 고려할 수 있습니다. 만약 2단계 인증이 강제되었고, 아무런 그룹이 선택되지 않았다면 제외된 그룹의 멤버를 제외하고 모든 유저에게 2단계 인증이 강제됩니다. 만약 그룹이 선택되었다면 그룹 안의 모든 멤버에게 2단계 인증이 강제됩니다. 만약 유저가 선택된 그룹과 제외된 그룹에 동시에 속해있다면, 선택된 그룹이 우선되며 2단계 인증이 강제됩니다.",
+    "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "그룹을 선택 또는 제외할 때, 이들의 2단계 인증 강제 여부는 다음과 같은 로직을 따릅니다: 만약 2단계 인증이 강제되었고, 아무런 그룹이 선택되지 않았다면 제외된 그룹의 멤버를 제외하고 모든 사용자에게 2단계 인증이 강제됩니다. 만약 그룹이 선택되었다면 그룹 안의 모든 멤버에게 2단계 인증이 강제됩니다. 만약 사용자가 선택된 그룹과 제외된 그룹에 동시에 속해 있다면, 선택된 그룹이 우선되며 2단계 인증이 강제됩니다.",
     "Save changes" : "변경 사항 저장",
     "All" : "모두",
     "Limit app usage to groups" : "앱 사용을 그룹으로 제한합니다.",
@@ -168,7 +171,6 @@ OC.L10N.register(
     "View in store" : "스토어에서 보기",
     "Visit website" : "웹 사이트 방문",
     "Report a bug" : "버그 신고",
-    "User documentation" : "사용자 문서",
     "Admin documentation" : "관리 문서",
     "Developer documentation" : "개발자 문서",
     "This app is supported via your current Nextcloud subscription." : "이 앱은 당신의 현재 Nextcloud 구독을 통해 지원됩니다.",
@@ -176,9 +178,13 @@ OC.L10N.register(
     "Featured" : "추천",
     "Update to {update}" : "{update}(으)로 업데이트",
     "All apps are up-to-date." : "모든 앱이 최신 버전입니다.",
+    "Icon" : "아이콘",
+    "Name" : "이름",
+    "Version" : "버전",
+    "Level" : "단계",
+    "Actions" : "동작",
     "No apps found for your version" : "설치된 버전에 대한 앱 없음",
     "Disable all" : "전체 비활성화",
-    "Enable all" : "모두 활성화",
     "_%n app has an update available_::_%n apps have an update available_" : ["%n앱을 업데이트 할 수 있습니다."],
     "_Update_::_Update all_" : ["모두 업데이트"],
     "Marked for remote wipe" : "원격 제거를 위해 지정됨",
@@ -214,10 +220,10 @@ OC.L10N.register(
     "Username" : "사용자 이름",
     "Password" : "암호",
     "Done" : "완료",
-    "Show QR code for mobile apps" : "모바일 앱을 위한 QR코드를 보여주십시오",
+    "Show QR code for mobile apps" : "모바일 앱을 위한 QR코드를 보여주세요.",
     "Copied!" : "복사 성공!",
     "Copy" : "복사",
-    "Could not copy app password. Please copy it manually." : "앱 비밀번호를 복사할 수 없습니다.  직접 옮겨 적으십시오.",
+    "Could not copy app password. Please copy it manually." : "앱 암호를 복사할 수 없습니다. 수동으로 복사해 주세요.",
     "For the server to work properly, it's important to configure background jobs correctly. Cron is the recommended setting. Please see the documentation for more information." : "서버가 적절하게 동작하기 위해 백그라운드 작업을 올바르게 설정하는 것이 중요합니다. Cron으로 설정하는 것을 권장합니다. 더 많은 정보는 문서를 참조하십시오.",
     "Last job execution ran {time}. Something seems wrong." : "마지막 작업이 {time}에 실행되었습니다. 무언가 잘못된 것 같습니다.",
     "Last job ran {relativeTime}." : "마지막 작업이 {relativeTime}에 실행되었음",
@@ -225,8 +231,6 @@ OC.L10N.register(
     "Execute one task with each page loaded. Use case: Single user instance." : "각 페이지를 로드할 때 마다 하나의 작업을 시행. 사용례: 1인 사용자 인스턴스",
     "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP. Use case: Very small instance (1–5 users depending on the usage)." : "cron.php를 webcron 서비스에 등록하여 cron.php를 매 5분마다 HTTP 상에서 호출. 사용례: 아주 작은 인스턴스 (사용자가 1~5명인 규모 - 사용량에 따라 다름)",
     "Cron (Recommended)" : "Cron (권장됨)",
-    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "이 항목을 실행하려면 PHP POSIX 확장이 필요합니다. 자세한 사항은 {linkstart}PHP 문서{linkend}를 참조하십시오.",
-    "Use system cron service to call the cron.php file every 5 minutes. Recommended for all instances." : "시스템 Cron 서비스를 사용하여 cron.php를 매 5분마다 호출. 모든 인스턴스에 권장.",
     "The cron.php needs to be executed by the system user \"{user}\"." : "시스템 사용자 \"{user}\"(으)로 cron.php를 실행해야 합니다.",
     "Unable to update background job mode" : "백그라운드 작업 모드를 업데이트 할 수 없음",
     "Profile" : "프로필",
@@ -236,7 +240,7 @@ OC.L10N.register(
     "Server-side encryption" : "서버 측 암호화",
     "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "서버 측 암호화를 사용하면 이 서버에 업로드되는 파일을 암호화할 수 있습니다. 성능 감소 등 제약 사항이 있으므로 필요한 경우에만 사용하십시오.",
     "Enable server-side encryption" : "서버 측 암호화 사용",
-    "Please read carefully before activating server-side encryption:" : "서버 측 암호화를 활성화하기 전에 읽어 보십시오:",
+    "Please read carefully before activating server-side encryption:" : "서버 측 암호화를 활성화하기 전에 읽어 보세요:",
     "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "암호화를 사용하면, 사용하기 시작한 시간 이후에 서버에 업로드된 모든 파일이 암호화됩니다. 나중에 암호화를 사용하지 않으려면 사용하고 있는 암호화 모듈에서 비활성화를 지원해야 하고 모든 사전 조건(예: 복구 키 설정)을 만족해야 합니다.",
     "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "암호화만으로 시스템의 보안을 보장할 수 없습니다. 암호화 응용 프로그램 작동 방식 및 지원되는 사용 사례에 대한 자세한 내용은 설명서를 참조하십시오.",
     "Be aware that encryption always increases the file size." : "암호화된 파일의 크기는 항상 커집니다.",
@@ -253,12 +257,15 @@ OC.L10N.register(
     "Current password" : "현재 암호",
     "New password" : "새 암호",
     "Change password" : "암호 변경",
-    "png or jpg, max. 20 MB" : "PNG, JPG, 최대 20MB",
+    "The file must be a PNG or JPG" : "파일은 PNG 또는 JPG여야 합니다.",
     "Picture provided by original account" : "원래 계정에서 제공하는 사진",
     "Cancel" : "취소",
+    "Please note that it can take up to 24 hours for your profile picture to be updated everywhere." : "프로필사진이 모든 곳에 갱신될 때까지 최대 24시간이 걸릴 수 있습니다.",
     "Your biography" : "내 소개문구",
     "Details" : "자세히",
     "You are a member of the following groups:" : "당신은 다음 그룹의 멤버입니다:",
+    "You are using <strong>{usage}</strong>" : "<strong>{usage}</strong>를 사용하고 있습니다.",
+    "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "전체 <strong>{totalSpace}</strong> 중 <strong>{usage}</strong>(<strong>{usageRelative}%</strong>)를 사용하고 있습니다.",
     "Your full name" : "내 전체 이름",
     "Email options" : "이메일 옵션",
     "Primary email for password reset and notifications" : "암호 초기화 및 알림 수신용 주 이메일 주소",
@@ -282,27 +289,44 @@ OC.L10N.register(
     "Unable to update language" : "언어를 갱신할 수 없음",
     "No language set" : "언어가 설정되지 않음",
     "Locale" : "지역",
+    "Week starts on {firstDayOfWeek}" : "일주일이 {firstDayOfWeek}에 시작함",
     "Your organisation" : "내 조직",
     "Your phone number" : "내 휴대폰 번호",
     "Edit your Profile visibility" : "프로필 표시 여부 편집",
     "Enable Profile" : "프로필 활성화",
     "Unable to update profile enabled state" : "프로필 활성화 여부를 갱신할 수 없음",
+    "The more restrictive setting of either visibility or scope is respected on your Profile. For example, if visibility is set to \"Show to everyone\" and scope is set to \"Private\", \"Private\" is respected." : "표시 여부나 표시 범위 설정은 더 좁은 쪽이 우선 적용됩니다. 예를 들어, 표시 여부는 \"전체 공개\", 표시 범위는 \"개인\"으로 설정되어 있다면, 해당 항목은 \"개인\"에게만 보여집니다.",
     "Unable to update visibility of {displayId}" : "{displayId}의 표시 여부를 갱신할 수 없음",
     "Your role" : "내 직책",
     "Your Twitter handle" : "내 트위터",
     "Your website" : "내 웹 사이트",
     "Add additional email" : "추가 이메일 추가",
     "Add" : "추가",
-    "You do not have permissions to see the details of this user" : "사용자의 상세정보를 볼 권한이 없습니다",
-    "Add new password" : "새로운 비밀번호를 입력하시오",
+    "Default language" : "기본 언어",
+    "Common languages" : "공통 언어",
+    "Other languages" : "다른 언어",
+    "Password change is disabled because the master key is disabled" : "마스터 키가 비활성화 되어 암호 변경이 비활성화 됨",
+    "New user" : "새 사용자",
+    "Display name" : "표시 이름",
+    "Email" : "이메일",
+    "Quota" : "할당량",
+    "Total rows summary" : "총 행 요약",
+    "Avatar" : "아바타",
+    "Group admin for" : "다음 그룹의 관리자:",
+    "User backend" : "사용자 백엔드",
+    "Storage location" : "저장소 위치",
+    "Last login" : "마지막 로그인",
+    "Add new password" : "새로운 암호 입력",
+    "You do not have permissions to see the details of this user" : "사용자의 상세정보를 볼 권한이 없습니다.",
     "Add new email address" : "새로운 이메일 추가하기",
     "Add user to group" : "사용자를 그룹에 추가",
     "Set user as admin for" : "사용자를 다음에 대한 관리자로 설정",
     "Select user quota" : "사용자 할당량 선택",
-    "Delete user" : "유저 지우기",
+    "{size} used" : "{size} 사용됨",
+    "Delete user" : "사용자 지우기",
     "Wipe all devices" : "모든 기기 지우기",
-    "Disable user" : "유저 비활성화하기",
-    "Enable user" : "유저 활성화하기",
+    "Disable user" : "사용자 비활성화하기",
+    "Enable user" : "사용자 활성화하기",
     "Resend welcome email" : "환영 메일 다시 보내기",
     "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "기기를 분실했거나 조직에서 이탈할 경우, 이를 통해 모든 기기에 있는 {userid} 관련 Nextcloud 데이터를 원격으로 삭제할 수 있습니다. 해당 기기들이 인터넷에 연결된 경우에 한하여 작동합니다.",
     "Remote wipe of devices" : "기기 원격 제거",
@@ -311,24 +335,13 @@ OC.L10N.register(
     "Account deletion" : "계정 삭제",
     "Delete {userid}'s account" : "{userid}의 계정 삭제",
     "Welcome mail sent!" : "환영 메일을 보냈습니다!",
-    "Edit User" : "사용자 편집",
-    "{size} used" : "{size} 사용됨",
-    "New user" : "새 사용자",
-    "Will be autogenerated" : "자동으로 생성될 것임",
-    "Display name" : "표시 이름",
-    "Email" : "이메일",
-    "Default language" : "기본 언어",
-    "Add a new user" : "새 사용자 추가",
-    "Group admin for" : "다음 그룹의 관리자:",
-    "Quota" : "할당량",
-    "User backend" : "사용자 백엔드",
-    "Storage location" : "저장소 위치",
-    "Last login" : "마지막 로그인",
-    "No users in here" : "사용자가 이곳에 없습니다.",
+    "Edit" : "편집",
+    "Show user backend" : "사용자 백엔드 보이기",
+    "Show storage path" : "스토리지 경로 보이기",
+    "Show last login" : "마지막 로그인 보이기",
+    "Send email" : "이메일 보내기",
     "Default quota" : "기본 할당량",
-    "Common languages" : "공통 언어",
-    "Other languages" : "다른 언어",
-    "Password change is disabled because the master key is disabled" : "마스터 키가 비활성화 되어 암호 변경이 비활성화 됨",
+    "Select default quota" : "기본 할당량 설정",
     "Passwordless authentication requires a secure connection." : "무암호 인증을 위해 보안 연결이 필요합니다.",
     "Add WebAuthn device" : "WebAuthn 기기 추가",
     "Please authorize your WebAuthn device." : "내 WebAuthn 기기를 인증하십시오.",
@@ -338,30 +351,18 @@ OC.L10N.register(
     "Server error while trying to complete WebAuthn device registration" : "WebAuthn 기기 등록을 마치는 중 오류 발생",
     "Unnamed device" : "이름 없는 장치",
     "Passwordless Authentication" : "무암호 인증",
-    "Set up your account for passwordless authentication following the FIDO2 standard." : "FIDO2 기준을 준수하여 계정에 무암호 인증을 설정하십시오",
+    "Set up your account for passwordless authentication following the FIDO2 standard." : "FIDO2 기준을 준수하여 계정에 무암호 인증을 설정하세요.",
     "No devices configured." : "설정된 기기가 없습니다.",
     "The following devices are configured for your account:" : "다음의 기기가 계정에 설정되었습니다:",
     "Your browser does not support WebAuthn." : "WebAuthn이 현재 브라우저를 지원하지 않습니다.",
     "Your apps" : "내 앱",
-    "Active apps" : "활성화된 앱",
-    "Disabled apps" : "비활성화된 앱",
-    "Updates" : "업데이트",
-    "App bundles" : "앱 번들",
-    "Featured apps" : "추천 앱 - ",
     "{license}-licensed" : "{license} 라이선스",
     "Changelog" : "변경 기록",
     "Enter group name" : "그룹 이름 입력",
     "Add group" : "그룹 추가",
     "Active users" : "활성 사용자",
     "Admins" : "관리자",
-    "Disabled users" : "비활성화된 유저",
-    "Default quota:" : "기본 할당량:",
-    "Select default quota" : "기본 할당량 설정",
-    "Show Languages" : "언어 보이기",
-    "Show last login" : "마지막 로그인 보이기",
-    "Show user backend" : "사용자 백엔드 보이기",
-    "Show storage path" : "스토리지 경로 보이기",
-    "Send email to new user" : "새 사용자에게 이메일 보내기",
+    "Disabled users" : "비활성화된 사용자",
     "Not saved" : "저장하지 않음",
     "Sending…" : "보내는 중…",
     "Email sent" : "이메일 보냄",
@@ -377,41 +378,41 @@ OC.L10N.register(
     "Twitter" : "트위터",
     "Website" : "웹사이트",
     "Profile visibility" : "프로필 표시 여부",
+    "Active apps" : "활성화된 앱",
+    "Disabled apps" : "비활성화된 앱",
+    "Updates" : "업데이트",
+    "App bundles" : "앱 번들",
+    "Featured apps" : "추천 앱 - ",
     "Show to everyone" : "전체 공개",
     "Show to logged in users only" : "로그인된 사용자에게 공개",
     "Hide" : "비공개",
     "Download and enable" : "다운로드 및 활성화",
-    "Enable untested app" : "미시험 앱 활성화",
-    "The app will be downloaded from the App Store" : "이 앱이 앱 스토어에서 다운로드됩니다",
+    "The app will be downloaded from the App Store" : "이 앱이 앱 스토어에서 다운로드됩니다.",
     "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "이 앱은 현재 Nextcloud 버젼과 호환되지 않습니다.  이 앱을 설치하면, 제대로 작동하지 않을 수 있습니다.",
     "Never" : "하지 않음",
     "An error occurred during the request. Unable to proceed." : "요청을 보내는 도중 에러가 발생하였습니다. 더 이상 진행할 수 없습니다.",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "앱이 활성화되었지만, 앱을 업데이트해야 합니다. 5초 후 앱 업데이트 페이지로 넘어갑니다.",
-    "Error: This app cannot be enabled because it makes the server unstable" : "오류: 이 앱은 서버를 불안정하게 만들 수 있어서 활성화할 수 없습니다",
-    "Administrator documentation" : "관리자 문서",
+    "Error: This app cannot be enabled because it makes the server unstable" : "오류: 이 앱은 서버를 불안정하게 만들 수 있어서 활성화할 수 없습니다.",
+    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "이 네트워크에 너무 요청이 많습니다. 나중에 다시 시도하십시오. 이것이 오류일 경우 관리자에게 문의하십시오.",
     "Documentation" : "문서",
     "Forum" : "포럼",
     "Login" : "로그인",
-    "Plain" : "일반",
-    "NT LAN Manager" : "NT LAN 관리자",
-    "SSL/TLS" : "SSL/TLS",
-    "STARTTLS" : "STARTTLS",
+    "SSL" : "SSL",
     "Open documentation" : "문서 열기",
     "It is important to set up this server to be able to send emails, like for password reset and notifications." : "암호 초기화 및 알림 이메일을 보내려면 이메일 서버를 설정해야 합니다.",
     "Send mode" : "보내기 모드",
     "Encryption" : "암호화",
     "Sendmail mode" : "Sendmail 모드",
     "From address" : "보낸 사람 주소",
-    "Authentication method" : "인증 방법",
-    "Authentication required" : "인증 필요함",
     "Server address" : "서버 주소",
     "Port" : "포트",
+    "Authentication" : "인증",
+    "Authentication required" : "인증 필요함",
     "Credentials" : "인증 정보",
     "SMTP Username" : "SMTP 사용자 이름",
     "SMTP Password" : "SMTP 암호",
     "Save" : "저장",
     "Test and verify email settings" : "이메일 설정 테스트 및 검증",
-    "Send email" : "이메일 보내기",
     "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "이 인스턴스의 보안과 성능을 위해서 모든 것이 정확하게 설정되어야 합니다. 그러기 위해서 자동적으로 몇 가지를 확인하겠습니다. 더 자세한 정보를 위해서 링크된 문서를 참고하세요.",
     "All checks passed." : "모든 검사를 통과했습니다.",
     "There are some errors regarding your setup." : "설정을 살펴본 결과 몇 가지 에러가 있습니다.",
@@ -419,7 +420,6 @@ OC.L10N.register(
     "Checking for system and security issues." : "시스템과 보안에 대한 문제를 확인하는 중",
     "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">설치 가이드 ↗</a>를 다시 한 번 확인한 다음 <a href=\"%2$s\">로그</a>의 경고나 에러를 확인하세요.",
     "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">우리의 보안 검사 ↗</a>에서 이 Nextcloud의 보안을 점검하세요.",
-    "Version" : "버전",
     "You need to enable the File sharing App." : "파일 공유 앱을 활성화해야 합니다.",
     "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "관리자로 공유 행동을 미세 조정할 수 있습니다. 더 많은 정보를 보려면 문서를 참조하십시오.",
     "Allow apps to use the Share API" : "앱에서 공유 API를 사용할 수 있도록 허용",
@@ -449,65 +449,25 @@ OC.L10N.register(
     "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "이 Nextcloud 커뮤니티 릴리즈는 지원되지 않으며 즉각적인 알림을 사용할 수 없습니다.",
     "Use a second factor besides your password to increase security for your account." : "사용자의 계정을 더욱 안전하게 보호하기 위해 암호와 함께 2단계 인증을 사용하세요.",
     "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Nextcloud에 연결하기 위해 서드파티 애플리케이션을 사용할 경우 2차 인증을 활성화하기 앞서 각 애플리케이션에 대한 앱 암호를 생성, 설정하십시오.",
-    "Migration in progress. Please wait until the migration is finished" : "이전 작업 중입니다. 작업이 완료될 때까지 기다려 주십시오",
-    "Migration started …" : "이전 시작됨...",
-    "An error occurred while changing your language. Please reload the page and try again." : "언어를 변경하는 중 오류가 발생했습니다. 페이지를 새로 고친 후 다시 시도하십시오.",
-    "An error occurred while changing your locale. Please reload the page and try again." : "지역을 변경하는 중 오류가 발생했습니다. 페이지를 새로 고친 후 다시 시도하십시오.",
-    "Select a profile picture" : "프로필 사진 선택",
-    "Week starts on {fdow}" : "{fdow} 에 한 주가 시작합니다.",
-    "Couldn't remove app." : "앱을 삭제할 수 없습니다.",
-    "Couldn't update app." : "앱을 업데이트할 수 없습니다.",
-    "Backend doesn't support password change, but the user's encryption key was updated." : "백엔드에서 암호 변경을 지원하지 않지만 사용자의 암호화 키는 업데이트되었습니다.",
-    "Could not determine if TLS version of cURL is outdated or not because an error happened during the HTTPS request against https://nextcloud.com. Please check the nextcloud log file for more details." : "https://nextcloud.com에 대한 HTTPS 요청 중 오류가 발생하여 cURL의 TLS 버전이 오래되었는지 확인할 수 없습니다. 자세한 정보는 Nextcloud 로그 파일을 참조하여 주십시오.",
-    "You need to set your user email before being able to send test emails." : "테스트 이메일을 보내기 전 내 주소를 설정해야 합니다.",
-    "Set as primary mail" : "주 이메일로 지정",
-    "Change privacy level of email" : "이메일에 대한 공개 단계 변경",
-    "All languages" : "모든 언어",
-    "Everyone" : "모두",
-    "An error occured during the request. Unable to proceed." : "요청을 보내는 도중 에러가 발생하였습니다. 더 이상 진행할 수 없습니다.",
-    "Test email settings" : "이메일 설정 시험",
-    "Please read carefully before activating server-side encryption: " : "서버 측 암호화를 활성화하기 전에 읽어 보십시오:",
-    "Enable encryption" : "암호화 사용",
-    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "과거에 사용하였던(ownCloud <= 8.0) 암호화된 데이터에서 키를 이전해야 합니다. \"기본 암호화 모듈\"을 활성화한 다음 'occ encryption:migrate'를 실행하십시오",
-    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "ownCloud 8.0 이하에서 사용한 이전 암호화 키를 새 키로 이전해야 합니다.",
-    "Start migration" : "이전 시작",
-    "Last job execution ran %s. Something seems wrong." : "마지막 작업이 %s에 실행되었습니다. 무언가 잘못된 것 같습니다.",
-    "Some jobs haven’t been executed since %s. Please consider increasing the execution frequency." : "%s 이래 몇 가지 작업이 실행되지 않았습니다. 실행 빈도의 증가를 고려하십시오. ",
-    "Some jobs didn’t execute since %s. Please consider switching to system cron." : "%s 이래 몇 가지 작업이 실행되지 않았습니다. 시스템의 cron으로 변경하는 것을 고려하십시오.",
-    "Last job ran %s." : "마지막 작업이 %s에 실행되었습니다.",
-    "Background job didn’t run yet!" : "배경 작업이 아직 실행되지 않았습니다!",
-    "For the server to work properly, it's important to configure background jobs correctly. \"Cron\" is the recommended setting. Please see the documentation for more information." : "서버가 적절하게 동작하기 위해 백그라운드 작업을 올바르게 설정하는 것이 중요합니다. \"Cron\"으로 설정하는 것을 권장합니다. 더 많은 정보는 문서를 참조하십시오.",
-    "Pick background job setting" : "백그라운드 작업 설정 선택",
-    "Recommended" : "추천",
-    "The cron.php needs to be executed by the system user \"%s\"." : "시스템 사용자 \"%s\"(으)로 cron.php를 실행해야 합니다.",
-    "days" : "일",
-    "Change privacy level of profile picture" : "프로필 사진에 대한 공개 단계 변경",
-    "Upload new" : "새로 업로드",
-    "Select from Files" : "파일에서 선택",
-    "Remove image" : "그림 삭제",
-    "Please note that it can take up to 24 hours for the avatar to get updated everywhere." : "아바타가 모든 곳에 갱신될 때 까지 최대 24시간이 걸릴 수 있습니다.",
-    "Choose as profile picture" : "프로필 사진으로 선택",
-    "You are using <strong>%s</strong>" : "현재 <strong>%s</strong>를 사용하고 있습니다.",
-    "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "현재 <strong>%2$s</strong> /%1$s</strong>(<strong>%3$s%%</strong>)를 사용하고 있습니다",
-    "Change privacy level of full name" : "전체 이름에 대한 공개 단계 변경",
-    "No display name set" : "표시 이름이 설정되지 않음",
-    "Change privacy level of phone number" : "전화번호에 대한 공개 단계 변경",
-    "Address" : "주소",
-    "Change privacy level of address" : "주소에 대한 공개 단계 변경",
-    "Your postal address" : "내 우편 주소",
-    "Change privacy level of website" : "웹사이트에 대한 공개 단계 변경",
-    "It can take up to 24 hours before the account is displayed as verified." : "계정이 확인된 것으로 표시될 때까지 최대 24시간이 걸릴 수 있습니다",
-    "Link https://…" : "링크 https://…",
-    "Change privacy level of Twitter profile" : "트위터 프로필에 대한 공개 단계 변경",
-    "Twitter handle @…" : "트위터 핸들 @…",
-    "The maximum number of OPcache keys is nearly exceeded. To assure that all scripts can be hold in cache, it is recommended to apply <code>opcache.max_accelerated_files</code> to your PHP configuration with a value higher than <code>%s</code>." : "곧 OPcache key가 최대치를 초과할 것으로 보입니다. 모든 스크립트가 캐시에 보관될 수 있도록, PHP 설정에서 <code>opcache.max_accelerated_files</code> 값을 <code>%s</code> 보다 크게 적용하시길 권장합니다. ",
-    "Admin privileges" : "관리자용 권한",
-    "Unable to update biography" : "소개문구를 갱신할 수 없음",
-    "Unable to update full name" : "전체 이름을 갱신할 수 없음",
-    "No full name set" : "전체 이름이 설정되지 않음",
-    "Unable to update headline" : "표제를 갱신할 수 없음",
-    "Unable to update organisation" : "조직을 갱신할 수 없음",
-    "Unable to update role" : "직책을 갱신할 수 없음",
-    "Avatar" : "아바타"
+    "You created app password \"{token}\"" : "앱 패스워드 \"{token}\"이 생성되었습니다.",
+    "An administrator created app password \"{token}\"" : "관리자가 앱 패스워드 \"{token}\"을(를) 생성함",
+    "Enable all" : "모두 활성화",
+    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "이 항목을 실행하려면 PHP POSIX 확장이 필요합니다. 자세한 사항은 {linkstart}PHP 문서{linkend}를 참조하십시오.",
+    "Use system cron service to call the cron.php file every 5 minutes. Recommended for all instances." : "시스템 Cron 서비스를 사용하여 cron.php를 매 5분마다 호출. 모든 인스턴스에 권장.",
+    "png or jpg, max. 20 MB" : "PNG, JPG, 최대 20MB",
+    "Your location" : "내 위치",
+    "Edit User" : "사용자 편집",
+    "Will be autogenerated" : "자동으로 생성될 것임",
+    "Add a new user" : "새 사용자 추가",
+    "No users in here" : "사용자가 이곳에 없습니다.",
+    "Default quota:" : "기본 할당량:",
+    "Show Languages" : "언어 보이기",
+    "Send email to new user" : "새 사용자에게 이메일 보내기",
+    "Enable untested app" : "미시험 앱 활성화",
+    "Plain" : "일반",
+    "NT LAN Manager" : "NT LAN 관리자",
+    "SSL/TLS" : "SSL/TLS",
+    "STARTTLS" : "STARTTLS",
+    "Authentication method" : "인증 방법"
 },
 "nplurals=1; plural=0;");
