@@ -25,17 +25,27 @@ OC.L10N.register(
     "State token does not match" : "狀態權杖不相符",
     "Invalid app password" : "無效的應用程式密碼",
     "Could not complete login" : "嘗試登入時發生錯誤",
+    "State token missing" : "狀態權杖遺失",
     "Your login token is invalid or has expired" : "您的登入權杖無效或已過期",
     "This community release of Nextcloud is unsupported and push notifications are limited." : "不支援 Nextcloud 的這個社群版本，且推播通知有所限制。",
     "Login" : "登入",
+    "Please try again" : "請再試一次",
     "Password reset is disabled" : "密碼重設已停用",
     "Could not reset password because the token is expired" : "無法重設密碼，因為權杖已過期",
     "Could not reset password because the token is invalid" : "無法重設密碼，因為權杖無效",
+    "Password is too long. Maximum allowed length is 469 characters." : "密碼太長。最大允許長度為 469 個字元。",
     "%s password reset" : "%s 密碼重設",
     "Password reset" : "密碼重設",
     "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "點選下方的按鈕來重設您的密碼。若您沒有要求重設密碼，請忽略這封信件。",
     "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "點取下方的連結以重設您的密碼。 如果您沒有要求重設密碼的話，請忽略這封信件。",
     "Reset your password" : "重設密碼",
+    "Requested task type does not exist" : "請求的任務類型不存在",
+    "Necessary language model provider is not available" : "無必要的語言模型提供者",
+    "Task not found" : "找不到任務",
+    "Internal error" : "內部錯誤",
+    "No translation provider available" : "沒有可用的翻譯提供者",
+    "Could not detect language" : "無法偵測語言",
+    "Unable to translate" : "無法翻譯",
     "Nextcloud Server" : "Nextcloud 伺服器",
     "Some of your link shares have been removed" : "部分分享連結己被移除",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "由於安全性問題，我們必須移除您一部分的連結分享。查看更多資訊請點選連結。",
@@ -48,7 +58,7 @@ OC.L10N.register(
     "Repair info:" : "修復資訊：",
     "Repair warning:" : "修復警告：",
     "Repair error:" : "修復錯誤：",
-    "Please use the command line updater because automatic updating is disabled in the config.php." : "由於自動更新功能已在 config.php 檔案中設定停用，請使用命令列更新系統。",
+    "Please use the command line updater because updating via browser is disabled in your config.php." : "因為透過瀏覽器更新的功能已在您的 config.php 中停用，因此請使用命令列更新程式。",
     "Turned on maintenance mode" : "啟用維護模式",
     "Turned off maintenance mode" : "停用維護模式",
     "Maintenance mode is kept active" : "伺服器正處於維護模式",
@@ -74,7 +84,9 @@ OC.L10N.register(
     "You have not set or verified your email server configuration, yet. Please head over to the {mailSettingsStart}Basic settings{mailSettingsEnd} in order to set them. Afterwards, use the \"Send email\" button below the form to verify your settings." : "您尚未設定或驗證您的電子郵件伺服器設定。請前往{mailSettingsStart}基本設定{mailSettingsEnd}進行設定。然後使用表單下方的「傳送電子郵件」按鈕來驗證您的設定。",
     "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "您的資料庫並未使用 \"READ COMMITTED\" 的交易隔離等級。當有多個行為平行進行時，這可能會造成問題。",
     "The PHP module \"fileinfo\" is missing. It is strongly recommended to enable this module to get the best results with MIME type detection." : "未偵測到 PHP 模組 \"fileinfo\"。強烈建議啟用這個模組，以取得最好的 MIME 檔案類型偵測支援。",
+    "Your remote address was identified as \"{remoteAddress}\" and is bruteforce throttled at the moment slowing down the performance of various requests. If the remote address is not your address this can be an indication that a proxy is not configured correctly. Further information can be found in the {linkstart}documentation ↗{linkend}." : "您的遠端地址被識別為「{remoteAddress}」，且目前正受到強力限制，導致降低了各種請求的效能。若遠端地址不是您的地址，可能代表代理伺服器設定不正確。可以在{linkstart}文件 ↗{linkend}中找到進一步的資訊。",
     "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems. See the {linkstart}documentation ↗{linkend} for more information." : "事務型文件鎖定的功能已經取消，這可能會造成競態條件，請在 config.php 中啟用 \"filelocking.enabled\" 以避免出現這樣的問題，請參考{linkstart}文件 ↗{linkend}來了解更多的資訊。",
+    "The database is used for transactional file locking. To enhance performance, please configure memcache, if available. See the {linkstart}documentation ↗{linkend} for more information." : "資料庫用於交易檔案鎖定。要強化效能，請設定 memcache（若可用）。請見{linkstart}文件 ↗{linkend}。",
     "Please make sure to set the \"overwrite.cli.url\" option in your config.php file to the URL that your users mainly use to access this Nextcloud. Suggestion: \"{suggestedOverwriteCliURL}\". Otherwise there might be problems with the URL generation via cron. (It is possible though that the suggested URL is not the URL that your users mainly use to access this Nextcloud. Best is to double check this in any case.)" : "請確定將 config.php 檔案中的 \"overwrite.cli.url\" 選項設定為您的使用者主要用於存取此 Nextcloud 的 URL。建議：\"{suggestedOverwriteCliURL}\"。否則，透過 cron 產生的 URL 可能會出現問題。（不過，建議的 URL 可能不是您的使用者主要用於存取此 Nextcloud 的 URL。最好是仔細檢查以防萬一。）",
     "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective {linkstart}ISO 3166-1 code ↗{linkend} of the region to your config file." : "你並未設定手機國際冠碼。設定後使用者在個人檔案設定手機號碼時不必再輸入國際冠碼。若要這樣做，請新增「default_phone_region」於設定檔，允許的國家及地區請參閱 {linkstart}ISO 3166-1 code ↗{linkend} 清單。",
     "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : " 無法透過 CLI 來執行排程工作，發生以下技術性錯誤：",
@@ -84,7 +96,7 @@ OC.L10N.register(
     "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the {linkstart}documentation ↗{linkend}." : "您沒有設定記憶體快取，如果可以，請設定 memcache 來提升效能。更多資訊請查閱{linkstart}文件 ↗{linkend}。",
     "No suitable source for randomness found by PHP which is highly discouraged for security reasons. Further information can be found in the {linkstart}documentation ↗{linkend}." : "PHP 無法取得合適的亂數產生源。為了安全性考量，不建議如此做。更多資訊參考{linkstart}文件 ↗{linkend}。",
     "You are currently running PHP {version}. Upgrade your PHP version to take advantage of {linkstart}performance and security updates provided by the PHP Group ↗{linkend} as soon as your distribution supports it." : "您目前正執行 PHP {version} ，我們建議您升級 PHP 到您的散佈版所支援的最新版本，以取得 {linkstart}PHP 開發團隊提供的效能與安全性更新 ↗{linkend}。",
-    "Nextcloud 23 is the last release supporting PHP 7.3. Nextcloud 24 requires at least PHP 7.4." : "Nextcloud 23 將是支援 PHP 7.3 的最後一個版本，Nextcloud 24 僅支援 PHP 7.4 以上的 PHP。",
+    "PHP 8.0 is now deprecated in Nextcloud 27. Nextcloud 28 may require at least PHP 8.1. Please upgrade to {linkstart}one of the officially supported PHP versions provided by the PHP Group ↗{linkend} as soon as possible." : "Nextcloud 27 已棄用 PHP 8.0。Nextcloud 28 需要 PHP 8.1 或更新版本。請盡快升級至 {linkstart}PHP Group ↗{linkend}提供官方支援的其中一個版本。",
     "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud. Further information can be found in the {linkstart}documentation ↗{linkend}." : "偵測到您的反向代理標頭設定不正確，但也有可能是因為您目前正透過信任的代理伺服器存取 Nextcloud。若您目前不是透過信任的代理伺服器存取 Nextcloud，這就是一個安全性問題，允許攻擊者對 Nextcloud 假冒 IP 位址。更多資訊請查閱{linkstart}文件 ↗{linkend}。",
     "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the {linkstart}memcached wiki about both modules ↗{linkend}." : "Memcached是用於分散式緩存的設置，但是目前安裝了錯誤的PHP模組為「memcache」。\\OC\\Memcache\\Memcached僅支援「memcached」而不是「memcache」。請參閱 {linkstart}memcached wiki了解兩種模組資訊 ↗{linkend}。",
     "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in the {linkstart1}documentation ↗{linkend}. ({linkstart2}List of invalid files…{linkend} / {linkstart3}Rescan…{linkend})" : "部份檔案未通過完整性檢查。更多關於如何解決此問題的資訊可在{linkstart1}文件 ↗{linkend}中找到。（{linkstart2}無效檔案列表……{linkend} / {linkstart3}重新掃描……{linkend}）",
@@ -100,6 +112,7 @@ OC.L10N.register(
     "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "您的 Nextcloud 缺少了某些建議的 PHP 模組。為了提升效能與相容性，強烈建議您安裝這些 PHP 模組。",
     "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "雖然已啟用佈景主題應用程式，但並未啟用 PHP 模組「imagick」。為了讓 favicon 產生流程正常運作，您必須安裝並啟用此模組。",
     "The PHP modules \"gmp\" and/or \"bcmath\" are not enabled. If you use WebAuthn passwordless authentication, these modules are required." : "未啟用 PHP 模組「gmp」與「bcmath」。若您要使用 WebAuthn 免密碼驗證，這些模組就是必要的。",
+    "It seems like you are running a 32-bit PHP version. Nextcloud needs 64-bit to run well. Please upgrade your OS and PHP to 64-bit! For further details read {linkstart}the documentation page ↗{linkend} about this." : "您似乎正在執行 32 位元版本的 PHP。Nextcloud 需要 64 位元才能運作良好。請將您的作業系統與 PHP 升級至 64 位元！要取得更多詳細資訊，請閱讀關於此問題的{linkstart}文件頁面 ↗{linkend}。",
     "Module php-imagick in this instance has no SVG support. For better compatibility it is recommended to install it." : "系統安裝的 php-imagick 不支援 SVG，為了更好的相容性，建議安裝它。",
     "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running \"occ db:convert-filecache-bigint\" those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read {linkstart}the documentation page about this ↗{linkend}." : "資料庫的有些欄位缺少 big int 格式轉換。因為欄位格式轉換需要一些時間，所以沒有自動轉換。您可以執行 \"occ db:convert-filecache-bigint\" 手動完成轉換，轉換時 Nextcloud 服務必須處於離線狀態。詳情請參閱{linkstart}關於這個問題的文件頁面 ↗{linkend}。",
     "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "目前您的後端資料庫使用 SQLite，在大型服務當中，我們建議您使用其他的資料庫後端。",
@@ -111,6 +124,7 @@ OC.L10N.register(
     "This instance uses an S3 based object store as primary storage. The uploaded files are stored temporarily on the server and thus it is recommended to have 50 GB of free space available in the temp directory of PHP. Check the logs for full details about the path and the available space. To improve this please change the temporary directory in the php.ini or make more space available in that path." : "此站台使用 Amazon S3 物件儲存為主要儲存區。上傳檔案會暫存在伺服器，因此建議 PHP 的暫存資料夾最少要有 50 GB 可用容量。請在登錄檔中查閱關於資料夾路徑及可用容量的詳細資訊。要增進效能，請在 php.ini 中變更暫存資料夾位置，或將該資料夾容量增加。",
     "The temporary directory of this instance points to an either non-existing or non-writable directory." : "此站台的臨時目錄指向一個不存在或無法寫入的目錄。",
     "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This most likely means that you are behind a reverse proxy and the overwrite config variables are not set correctly. Please read {linkstart}the documentation page about this ↗{linkend}." : "你經由安全的連線存取系統，但系統卻生成了不安全的 URL。這很有可能是因為你使用了反向代理伺服器，但反向代理伺服器的改寫規則並未正常工作，請閱讀{linkstart}關於此問題的文件頁面 ↗{linkend}。",
+    "This instance is running in debug mode. Only enable this for local development and not in production environments." : "此站台以除錯模式執行。僅在本機開發且非生產環境時才啟用這個。",
     "Error occurred while checking server setup" : "檢查伺服器設定時發生錯誤",
     "For more details see the {linkstart}documentation ↗{linkend}." : "更多詳細資訊請見{linkstart}文件 ↗{linkend}。",
     "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "您的資料目錄和檔案看來可以被公開存取，這表示 .htaccess 設定檔並未生效，我們強烈建議您設定網頁伺服器，拒絕公開存取資料目錄，或者將您的資料目錄移出網頁伺服器根目錄。",
@@ -119,7 +133,7 @@ OC.L10N.register(
     "The \"{header}\" HTTP header does not contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "目前 HTTP 的 \"{header}\" 標頭設定並不包含 \"{expected}\" ，這是一個潛在的安全性和隱私風險，我們建議調整此項設定。",
     "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the {linkstart}W3C Recommendation ↗{linkend}." : "目前 HTTP 的 \"{header}\" 標頭設定並不是 \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" 或 \"{val5}\"，這將會洩漏一些訊息。{linkstart}請參考 W3C 建議文件 ↗{linkend}。",
     "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the {linkstart}security tips ↗{linkend}." : "HTTP \"Strict-Transport-Security\" 標頭並未被設定持續至少{seconds}秒。為了提高安全性，我們在{linkstart}安全建議 ↗{linkend}中有詳述並建議啟用 HSTS。",
-    "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead, as described in the {linkstart}security tips ↗{linkend}." : "您正在透過不安全的 HTTP 存取網站，強烈建議您設定您的伺服器啟用 HTTPS，更多資訊請查閱{linkstart}安全建議 ↗{linkend}。",
+    "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead, as described in the {linkstart}security tips ↗{linkend}. Without it some important web functionality like \"copy to clipboard\" or \"service workers\" will not work!" : "您正在透過不安全的 HTTP 存取網站，強烈建議您設定您的伺服器啟用 HTTPS，更多資訊請查閱{linkstart}安全建議 ↗{linkend}。若不將伺服器設定為以 HTTPS 運作，部份重要的網站功能，如「複製到剪貼簿」或「Service Worker」將無法運作！",
     "unknown text" : "未知的文字",
     "Hello world!" : "哈囉，世界！",
     "sunny" : "晴朗的",
@@ -145,12 +159,13 @@ OC.L10N.register(
     "Please contact your administrator." : "請聯絡系統管理員",
     "An internal error occurred." : "發生內部錯誤",
     "Please try again or contact your administrator." : "請重試或聯絡系統管理員",
-    "Log in to {productName}" : "登入至 {productName}",
     "Account name or email" : "帳號名稱或電子郵件",
     "Password" : "密碼",
+    "Log in to {productName}" : "登入至 {productName}",
     "Wrong username or password." : "錯誤的使用者名稱 或 密碼",
     "User disabled" : "使用者已遭停用",
     "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "您的 IP 多次嘗試登入無效。因此下一次登入將會被延時30秒。",
+    "Log in with a device" : "使用免密碼裝置登入",
     "Username or email" : "使用者名稱或電子郵件",
     "Your account is not setup for passwordless login." : "你的帳號尚未設定免密碼登入。",
     "Browser not supported" : "不支援的瀏覽器",
@@ -158,8 +173,7 @@ OC.L10N.register(
     "Your connection is not secure" : "您的連線不安全",
     "Passwordless authentication is only available over a secure connection." : "無密碼身份驗證僅支援經加密的連線。",
     "Reset password" : "重設密碼",
-    "A password reset message has been sent to the email address of this account. If you do not receive it, check your spam/junk folders or ask your local administrator for help." : "重設密碼資訊已寄至您的電子郵件。若您並未收到該信件，請確認您垃圾信箱，或請求管理員協助。",
-    "If it is not there ask your local administrator." : "你找的東西不在，請聯絡管理員。",
+    "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or account name, check your spam/junk folders or ask your local administration for help." : "若此帳號存在，密碼重設郵件即已寄送至其電子郵件地址。若您未收到，請驗證您的電子郵件地址及/或帳號名稱，並檢查您的垃圾郵件資料夾，或向您的本機管理員求助。",
     "Couldn't send reset email. Please contact your administrator." : "無法寄出重設密碼資訊。請聯絡您的管理員。",
     "Password cannot be changed. Please contact your administrator." : "密碼無法變更。請聯絡您的管理員。",
     "Back to login" : "回到登入畫面",
@@ -181,8 +195,10 @@ OC.L10N.register(
     "Simple email app nicely integrated with Files, Contacts and Calendar." : "簡潔的電子郵件應用程式，與檔案瀏覽器、通訊錄、行事曆完美整合",
     "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "對話、視訊電話、螢幕分享、線上會議與網路研討會 - 實現於你的瀏覽器與手機應用程式之中。",
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "使用 Collabora Online 建置的協作文件、試算表與簡報。",
+    "Distraction free note taking app." : "無干擾的筆記應用程式。",
+    "Search contacts" : "搜尋聯絡人",
     "Forgot password?" : "忘記密碼？",
-    "Log in with a device" : "使用免密碼裝置登入",
+    "Back to login form" : "回到登入表單",
     "Back" : "返回",
     "Login form is disabled." : "登入表單已停用。",
     "Edit Profile" : "編輯個人檔案",
@@ -190,16 +206,16 @@ OC.L10N.register(
     "You have not added any info yet" : "您尚未新增任何資訊。",
     "{user} has not added any info yet" : "{user} 尚未新增任何資訊。",
     "Error opening the user status modal, try hard refreshing the page" : "開啟使用者狀態模式時發生問題，嘗試重新整理頁面",
-    "Search starts once you start typing" : "開始輸入後開始搜尋",
+    "Search starts once you start typing and results may be reached with the arrow keys" : "一旦您開始輸入，搜尋就會開始，您可以使用方向鍵到達結果",
     "Reset search" : "重置搜尋",
     "Start search" : "開始搜尋",
     "Search for {name} only" : "僅搜尋 {name}",
-    "No results for {query}" : "{query} 查詢沒有結果",
-    "Press enter to start searching" : "按 Enter 以開始搜尋",
     "Start typing to search" : "開始輸入以搜尋",
     "Loading more results …" : "正在載入更多結果…",
     "Load more results" : "載入更多結果",
     "Search" : "搜尋",
+    "No results for {query}" : "{query} 查詢沒有結果",
+    "Press Enter to start searching" : "按 Enter 開始搜尋",
     "An error occurred while searching for {type}" : "搜尋 {type} 時發生錯誤",
     "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["請輸入 {minSearchLength} 個或以上字元搜尋"],
     "This browser is not supported" : "不支援此瀏覽器",
@@ -207,10 +223,11 @@ OC.L10N.register(
     "Continue with this unsupported browser" : "繼續使用此不受支援的瀏覽器",
     "Supported versions" : "支援的版本",
     "{name} version {version} and above" : "{name} 的版本 {version} 及更新",
+    "Open settings menu" : "開啟設定選單",
+    "Settings menu" : "設定選單",
     "Search {types} …" : "搜尋 {types} 中……",
-    "Settings" : "設定",
+    "Avatar of {fullName}" : "{fullName} 的大頭照",
     "Could not load your contacts" : "無法載入您的聯絡人",
-    "Search contacts …" : "搜尋聯絡人……",
     "No contacts found" : "查無聯絡人",
     "Show all contacts …" : "顯示所有聯絡人…",
     "Install the Contacts app" : "安裝「通訊錄」應用程式",
@@ -218,21 +235,12 @@ OC.L10N.register(
     "Looking for {term} …" : "搜尋 {term}……",
     "No" : "否",
     "Yes" : "是",
-    "No files in here" : "沒有任何檔案",
-    "New folder" : "新增資料夾",
-    "No more subfolders in here" : "這裡沒有其他子資料夾了",
-    "Name" : "姓名",
-    "Size" : "大小",
-    "Modified" : "已修改",
-    "\"{name}\" is an invalid file name." : "{name} 是無效的檔名",
-    "File name cannot be empty." : "檔名不能為空",
-    "\"/\" is not allowed inside a file name." : "不允許檔名中出現 \"/\"。",
-    "\"{name}\" is not an allowed filetype" : "\"{name}\" 是不允許的檔案類型",
-    "{newName} already exists" : "{newName} 已經存在",
+    "Choose {file}" : "選擇 {file}",
     "Choose" : "選擇",
+    "Copy to {target}" : "複製到 {target}",
     "Copy" : "複製",
+    "Move to {target}" : "移動至 {target}",
     "Move" : "移動",
-    "Error loading file picker template: {error}" : "載入檔案選擇器範本時發生錯誤：{error}",
     "OK" : "OK",
     "Error loading message template: {error}" : "載入訊息範本時發生錯誤：{error}",
     "read-only" : "唯讀",
@@ -247,11 +255,6 @@ OC.L10N.register(
     "(all selected)" : "（已全選）",
     "({count} selected)" : "（已選取 {count} 項）",
     "Error loading file exists template" : "載入已存在的範本時發生錯誤",
-    "Show list view" : "顯示清單檢視",
-    "Show grid view" : "顯示網格檢視",
-    "Pending" : "擱置中",
-    "Copy to {folder}" : "複製到 {folder}",
-    "Move to {folder}" : "移動到 {folder}",
     "Saving …" : "儲存中……",
     "Authentication required" : "必須驗證",
     "This action requires you to confirm your password" : "這個動作需要您再次確認密碼",
@@ -278,6 +281,7 @@ OC.L10N.register(
     "Strong password" : "密碼安全性極佳",
     "No action available" : "沒有可用的動作",
     "Error fetching contact actions" : "擷取聯絡人時發生錯誤",
+    "Close \"{dialogTitle}\" dialog" : "關閉「{dialogTitle}」對話方塊",
     "Non-existing tag #{tag}" : "不存在的標籤 #{tag}",
     "Restricted" : "受限",
     "Invisible" : "隱藏",
@@ -295,7 +299,7 @@ OC.L10N.register(
     "The profile does not exist." : "個人檔案不存在。",
     "Back to %s" : "回到 %s",
     "Page not found" : "找不到頁面",
-    "The page could not be found on the server." : "無法在伺服器上找到此頁面。",
+    "The page could not be found on the server or you may not be allowed to view it." : "在伺服器上找不到該頁面，或者您可能無法檢視它。",
     "Too many requests" : "太多要求",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "有太多請求來自你的網路，請稍後再試，若你認為這不該發生，請回報系統管理員這項錯誤。",
     "Error" : "錯誤",
@@ -346,10 +350,7 @@ OC.L10N.register(
     "Skip to main content" : "跳到主內容",
     "Skip to navigation of app" : "跳到應用程式導覽",
     "Get your own free account" : "取得免費帳號",
-    "%s's homepage" : "%s 的首頁",
-    "Contacts" : "聯絡人",
-    "Contacts menu" : "聯絡人選單",
-    "Open settings menu" : "開啟設定選單",
+    "Go to %s" : "前往 %s",
     "Confirm your password" : "確認密碼",
     "Connect to your account" : "連結您的帳號",
     "Please log in before granting %1$s access to your %2$s account." : "請登入後再授權「%1$s」存取您的 %2$s 帳號",
@@ -369,7 +370,6 @@ OC.L10N.register(
     "Email address" : "電子郵件地址",
     "Password sent!" : "密碼已傳送！",
     "You are not authorized to request a password for this share" : "您無權為此分享請求密碼",
-    "Go to %s" : "前往 %s",
     "Two-factor authentication" : "雙因素驗證",
     "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "您的帳號已啟用進階安全機制，請選擇一個雙因素驗證方法：",
     "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "無法載入任何一個雙因素認證方法，請聯絡管理員",
@@ -402,30 +402,34 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "這個 %s 安裝目前處於維護模式，需要一段時間恢復。",
     "This page will refresh itself when the instance is available again." : "安裝恢復可用之後，本頁會自動重新整理",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "若這個訊息持續出現，請聯絡系統管理員",
-    "Enter your subscription key to increase the user limit. For more information about Nextcloud Enterprise see our website." : "輸入您的訂閱金鑰以增加使用者限制。要取得更多關於 Nextcloud 企業版的資訊，請見我們的網站。",
-    "[%d / %d]: Checking table %s" : "[%d / %d]: 檢查資料表 %s",
-    "This server has no working Internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the Internet to enjoy all features." : "伺服器沒有網際網路連線（無法與多個端點取得聯繫），有些功能，像是外部儲存、應用程式更新版通知將無法運作。從遠端存取資料或是寄送電子郵件通知可能也無法運作。建議您設定好網際網路連線以使用所有功能。",
-    "Nextcloud 20 is the last release supporting PHP 7.2. Nextcloud 21 requires at least PHP 7.3." : "Nextcloud 20 將是支援 PHP 7.2 的最後一個版本，Nextcloud 21 僅支援 PHP 7.3 以上的 PHP。",
-    "The PHP OPcache module is not loaded. {linkstart}For better performance it is recommended ↗{linkend} to load it into your PHP installation." : "PHP 的 OPcache 模組並未被載入。{linkstart}為了提供更好的效能，建議 ↗{linkend}將此 PHP 模組載入。",
-    "The PHP OPcache module is not properly configured. {linkstart}For better performance it is recommended ↗{linkend} to use the following settings in the <code>php.ini</code>:" : "PHP 的 OPcache 模組並未被妥善設定。{linkstart}為了有更好的效能表現 ↗{linkend}，我們建議在 <code>php.ini</code> 設定檔中使用以下設定：",
-    "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running 'occ db:convert-filecache-bigint' those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read {linkstart}the documentation page about this ↗{linkend}." : "資料庫的有些欄位缺少 big int 格式轉換。因為攔位格式轉換需要一些時間，所以沒有自動轉換。你可以執行 \"occ db:convert-filecache-bigin\" 手動完成轉換，轉換時 Nextcloud 服務必須處於離線狀態。詳情請參閱{linkstart}關於這個問題的文件頁面 ↗{linkend}。",
-    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the {linkstart}documentation ↗{linkend}." : "若要遷移至另一個資料庫，請使用命令列工具： 'occ db:convert-type' ，或是查閱{linkstart}文件 ↗{linkend}。",
-    "Your data directory and files are probably accessible from the Internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "您的資料目錄和檔案看來可以被公開存取，這表示 .htaccess 設定檔並未生效，我們強烈建議您設定網頁伺服器，拒絕公開存取資料目錄，或者將您的資料目錄移出網頁伺服器根目錄。",
-    "The \"{header}\" HTTP header doesn't contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "目前 HTTP 的 \"{header}\" 標頭設定並不包含 \"{expected}\" ，這是一個潛在的安全性和隱私風險，我們建議調整此項設定。",
-    "Collaboratively edit office documents." : "協同編輯辦公室文件。",
-    "Local document editing back-end used by the Collabora Online app." : "由 Collabora Online 應用程式使用的本機文件編輯後端。",
-    "restricted" : "受限",
-    "invisible" : "不可見",
+    "Please use the command line updater because updating via the browser is disabled in your config.php." : "因為透過瀏覽器更新的功能已在您的 config.php 中停用，因此請使用命令列更新程式。",
+    "It seems like you are running a 32-bit PHP version. Nextcloud needs 64-bit to run well. Please upgrade your OS and PHP to 64-bit! For further details read {linkstart}the documentation page about this ↗{linkend}." : "您似乎正在執行 32 位元版本的 PHP。Nextcloud 需要 64 位元才能運作良好。請將您的作業系統與 PHP 升級至 64 位元！要取得更多詳細資訊，請閱讀{linkstart}關於此問題的文件 ↗{linkend}。",
+    "A password reset message has been sent to the email address of this account. If you do not receive it, check your spam/junk folders or ask your local administrator for help." : "重設密碼資訊已寄至您的電子郵件。若您並未收到該信件，請確認您垃圾信箱，或請求管理員協助。",
+    "If it is not there ask your local administrator." : "你找的東西不在，請聯絡管理員。",
+    "Press enter to start searching" : "按 Enter 以開始搜尋",
+    "Settings" : "設定",
+    "Search contacts …" : "搜尋聯絡人……",
+    "No files in here" : "沒有任何檔案",
+    "New folder" : "新增資料夾",
+    "No more subfolders in here" : "這裡沒有其他子資料夾了",
+    "Name" : "姓名",
+    "Size" : "大小",
+    "Modified" : "已修改",
+    "\"{name}\" is an invalid file name." : "{name} 是無效的檔名",
+    "File name cannot be empty." : "檔名不能為空",
+    "\"/\" is not allowed inside a file name." : "不允許檔名中出現 \"/\"。",
+    "\"{name}\" is not an allowed filetype" : "\"{name}\" 是不允許的檔案類型",
+    "{newName} already exists" : "{newName} 已經存在",
+    "Error loading file picker template: {error}" : "載入檔案選擇器範本時發生錯誤：{error}",
+    "Show list view" : "顯示清單檢視",
+    "Show grid view" : "顯示網格檢視",
+    "Pending" : "擱置中",
+    "Home" : "家",
+    "Copy to {folder}" : "複製到 {folder}",
+    "Move to {folder}" : "移動到 {folder}",
     "File not found" : "找不到檔案",
     "The document could not be found on the server. Maybe the share was deleted or has expired?" : "伺服器上找不到該文件，或許這個分享已經被刪除或是過期了？",
-    "More" : "更多",
-    "More apps menu" : "更多應用程式選單",
-    "Settings menu" : "設定選單",
-    "The password is wrong. Try again." : "密碼錯誤，請重試",
-    "Setup two-factor authentication" : "設定雙因素驗證",
-    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "不支援 Nextcloud 的這個社群版本，且即時通知不可用。",
-    "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications have been disabled to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at nextcloud.com/enterprise." : "這是不受支援的 Nextcloud 社群版建置。鑑於此站台的大小，無法保證效能、可靠程度與延展性。推播通知已被停用，以避免我們的免費服務負載過重。請至 nextcloud.com/enterprise 取得更多關於 Nextcloud 企業版的資訊。",
-    "You haven't added any info yet" : "您尚未新增任何資訊",
-    "{user} hasn't added any info yet" : "{user} 尚未新增任何資訊"
+    "Please use the command line updater because automatic updating is disabled in the config.php." : "由於自動更新功能已在 config.php 檔案中設定停用，請使用命令列更新系統。",
+    "The page could not be found on the server." : "無法在伺服器上找到此頁面。"
 },
 "nplurals=1; plural=0;");
